NetworkException class

A network request failed.

Inheritance

Constructors

NetworkException([String message = 'A network error occurred'])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of what went wrong.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited