AppNavigator class

Handles navigation operations using auto_route

Implemented types

Constructors

AppNavigator(BaseAppRouter? _appRouter, {bool enableNavigationLogs = true})
Creates an AppNavigator instance with the provided BaseAppRouter
const

Properties

enableNavigationLogs bool
Controls whether navigation logs are printed
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAndPush(PageRouteInfo<Object?> route) Future<void>?
Clears the entire navigation stack and pushes a new route
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop<T extends Object?>([T? result]) Future<bool>?
Pops the current route off the navigation stack
override
popTop<T extends Object?>([T? result]) Future<bool>?
override
popUntil(PageRouteInfo<Object?> route) Future<void>?
Pops all routes until reaching the specified route
override
push<T extends Object?>(PageRouteInfo<Object?> route) Future<T?>?
Pushes a new route onto the navigation stack
override
replace<T extends Object?>(PageRouteInfo<Object?> route) Future<T?>?
Replaces the current route with a new one
override
replaceAllWith(PageRouteInfo<Object?> route) Future<void>?
Replaces all routes in the stack with a single new route
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited