presentation/bloc/common_bloc library

Classes

ClearComponentLoading
Force-clears a loading key regardless of how many operations hold it.
CommonBloc
CommonEvent
Base class for all common application-wide events.
CommonState
Represents the state of common application-wide features.
SetComponentLoading
Event to control loading state for a specific component or operation.