presentation/base/i_state_manager library
Classes
-
IStateManager<
S> - The contract a page's state manager must satisfy to be driven by a base page.
Functions
-
debugAssertSingletonRegistration<
T extends Object> (GetIt di) → void -
Verifies that
Tis registered with a lifetime the page family supports.